@@ -19,6 +19,7 @@ package org.apache.maven.scm.provider;
  * under the License.
  */
 
+import org.apache.maven.scm.CommandParameters;
 import org.apache.maven.scm.ScmBranch;
 import org.apache.maven.scm.ScmBranchParameters;
 import org.apache.maven.scm.ScmException;
@@ -26,18 +27,25 @@ import org.apache.maven.scm.ScmFileSet;
 import org.apache.maven.scm.ScmTagParameters;
 import org.apache.maven.scm.ScmVersion;
 import org.apache.maven.scm.command.add.AddScmResult;
+import org.apache.maven.scm.command.blame.BlameScmRequest;
+import org.apache.maven.scm.command.blame.BlameScmResult;
 import org.apache.maven.scm.command.branch.BranchScmResult;
+import org.apache.maven.scm.command.changelog.ChangeLogScmRequest;
 import org.apache.maven.scm.command.changelog.ChangeLogScmResult;
 import org.apache.maven.scm.command.checkin.CheckInScmResult;
 import org.apache.maven.scm.command.checkout.CheckOutScmResult;
 import org.apache.maven.scm.command.diff.DiffScmResult;
 import org.apache.maven.scm.command.edit.EditScmResult;
 import org.apache.maven.scm.command.export.ExportScmResult;
+import org.apache.maven.scm.command.info.InfoScmResult;
 import org.apache.maven.scm.command.list.ListScmResult;
+import org.apache.maven.scm.command.mkdir.MkdirScmResult;
+import org.apache.maven.scm.command.remoteinfo.RemoteInfoScmResult;
 import org.apache.maven.scm.command.remove.RemoveScmResult;
 import org.apache.maven.scm.command.status.StatusScmResult;
 import org.apache.maven.scm.command.tag.TagScmResult;
 import org.apache.maven.scm.command.unedit.UnEditScmResult;
+import org.apache.maven.scm.command.untag.UntagScmResult;
 import org.apache.maven.scm.command.update.UpdateScmResult;
 import org.apache.maven.scm.log.ScmLogger;
 import org.apache.maven.scm.repository.ScmRepository;
@@ -50,7 +58,7 @@ import java.util.List;
 
 /**
  * @author <a href="mailto:evenisse@apache.org">Emmanuel Venisse</a>
- * @version $Id: ScmProvider.java 892494 2009-12-19 18:40:43Z olamy $
+ *
  */
 public interface ScmProvider
 {
@@ -80,7 +88,7 @@ public interface ScmProvider
      * @param delimiter      The delimiter used in the SCM url
      * @return Returns a list of messages if the validation failed
      */
-    List validateScmUrl( String scmSpecificUrl, char delimiter );
+    List<String> validateScmUrl( String scmSpecificUrl, char delimiter );
 
     /**
      * Returns the scm reserved file name where the SCM stores information like 'CVS', '.svn'.
@@ -128,6 +136,18 @@ public interface ScmProvider
     AddScmResult add( ScmRepository repository, ScmFileSet fileSet, String message )
         throws ScmException;
 
+    /**
+     * Adds the given files to the source control system
+     *
+     * @param repository        the source control system
+     * @param fileSet           the files to be added
+     * @param commandParameters {@link CommandParameters}
+     * @return an {@link AddScmResult} that contains the files that have been added
+     * @throws ScmException if any
+     */
+    AddScmResult add( ScmRepository repository, ScmFileSet fileSet, CommandParameters commandParameters )
+        throws ScmException;
+
     /**
      * Branch (or label in some systems) will create a branch of the source file with a certain branch name
      *
@@ -135,9 +155,9 @@ public interface ScmProvider
      * @param fileSet    the files to branch. Implementations can also give the changes
      *                   from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param branchName the branch name to apply to the files
-     * @deprecated use {@link #branch(ScmRepository, ScmFileSet, String, String, ScmBranchParameters)}
      * @return
      * @throws ScmException if any
+     * @deprecated use {@link #branch(ScmRepository, ScmFileSet, String, String, ScmBranchParameters)}
      */
     BranchScmResult branch( ScmRepository repository, ScmFileSet fileSet, String branchName )
         throws ScmException;
@@ -150,31 +170,31 @@ public interface ScmProvider
      *                   from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param branchName the branch name to apply to the files
      * @param message    the commit message used for the tag creation
-     * @deprecated use {@link #branch(ScmRepository, ScmFileSet, String, String, ScmBranchParameters)}
      * @return
      * @throws ScmException if any
+     * @deprecated use {@link #branch(ScmRepository, ScmFileSet, String, String, ScmBranchParameters)}
      */
     BranchScmResult branch( ScmRepository repository, ScmFileSet fileSet, String branchName, String message )
         throws ScmException;
-    
+
     /**
      * Branch (or label in some systems) will create a branch of the source file with a certain
      * branch name
-     * 
+     *
      * @param repository the source control system
-     * @param fileSet the files to branch. Implementations can also give the changes from the
-     *            {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
+     * @param fileSet    the files to branch. Implementations can also give the changes from the
+     *                   {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param branchName the branch name to apply to the files
-     * @param message the commit message used for the tag creation
-     * @since 1.3
      * @return
      * @throws ScmException if any
+     * @since 1.3
      */
-    BranchScmResult branch( ScmRepository repository, ScmFileSet fileSet, String branchName, ScmBranchParameters scmBranchParameters )
-        throws ScmException;    
+    BranchScmResult branch( ScmRepository repository, ScmFileSet fileSet, String branchName,
+                            ScmBranchParameters scmBranchParameters )
+        throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system in a certain period of time.
+     * Returns the changes that have happened in the source control system in a certain period of time.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository the source control system
@@ -187,14 +207,15 @@ public interface ScmProvider
      * @return The SCM result of the changelog command
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#changeLog(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,java.util.Date,java.util.Date,int,org.apache.maven.scm.ScmBranch)}
+     *             org.apache.maven.scm.ScmFileSet, java.util.Date, java.util.Date, int,
+     *             org.apache.maven.scm.ScmBranch)}
      */
     ChangeLogScmResult changeLog( ScmRepository repository, ScmFileSet fileSet, Date startDate, Date endDate,
                                   int numDays, String branch )
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system in a certain period of time.
+     * Returns the changes that have happened in the source control system in a certain period of time.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository the source control system
@@ -206,13 +227,15 @@ public interface ScmProvider
      * @param branch     the branch/tag
      * @return The SCM result of the changelog command
      * @throws ScmException if any
+     * @deprecated use {@link #changeLog(org.apache.maven.scm.command.changelog.ChangeLogScmRequest)} instead
      */
+    @Deprecated
     ChangeLogScmResult changeLog( ScmRepository repository, ScmFileSet fileSet, Date startDate, Date endDate,
                                   int numDays, ScmBranch branch )
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system in a certain period of time.
+     * Returns the changes that have happened in the source control system in a certain period of time.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository  the source control system
@@ -225,15 +248,15 @@ public interface ScmProvider
      * @param datePattern the date pattern use in changelog output returned by scm tool
      * @return The SCM result of the changelog command
      * @throws ScmException if any
-     * @deprecated you must use {@link ScmProvider#changeLog(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,java.util.Date,java.util.Date,int,org.apache.maven.scm.ScmBranch,String)}
+     * @deprecated use {@link #changeLog(org.apache.maven.scm.command.changelog.ChangeLogScmRequest)} instead
      */
+    @Deprecated
     ChangeLogScmResult changeLog( ScmRepository repository, ScmFileSet fileSet, Date startDate, Date endDate,
                                   int numDays, String branch, String datePattern )
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system in a certain period of time.
+     * Returns the changes that have happened in the source control system in a certain period of time.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository  the source control system
@@ -241,18 +264,31 @@ public interface ScmProvider
      *                    from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param startDate   the start date of the period
      * @param endDate     the end date of the period
-     * @param numDays     the number days before the current time if startdate and enddate are null
+     * @param numDays     the number days before the current time if startDate and endDate are null
      * @param branch      the branch/tag
      * @param datePattern the date pattern use in changelog output returned by scm tool
      * @return The SCM result of the changelog command
      * @throws ScmException if any
+     * @deprecated use {@link #changeLog(org.apache.maven.scm.command.changelog.ChangeLogScmRequest)} instead
      */
     ChangeLogScmResult changeLog( ScmRepository repository, ScmFileSet fileSet, Date startDate, Date endDate,
                                   int numDays, ScmBranch branch, String datePattern )
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system between two tags.
+     * Returns the changes that have happened in the source control system in a certain period of time.
+     * This can be adding, removing, updating, ... of files
+     *
+     * @param scmRequest request wrapping detailed parameters for the changelog command
+     * @return The SCM result of the changelog command
+     * @throws ScmException if any
+     * @since 1.8
+     */
+    ChangeLogScmResult changeLog( ChangeLogScmRequest scmRequest )
+        throws ScmException;
+
+    /**
+     * Returns the changes that have happened in the source control system between two tags.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository the source control system
@@ -262,14 +298,14 @@ public interface ScmProvider
      * @param endTag     the end tag
      * @return The SCM result of the changelog command
      * @throws ScmException if any
-     * @deprecated you must use {@link ScmProvider#changeLog(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,org.apache.maven.scm.ScmVersion)}
+     * @deprecated use {@link #changeLog(org.apache.maven.scm.command.changelog.ChangeLogScmRequest)} instead
      */
+    @Deprecated
     ChangeLogScmResult changeLog( ScmRepository repository, ScmFileSet fileSet, String startTag, String endTag )
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system between two tags.
+     * Returns the changes that have happened in the source control system between two tags.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository   the source control system
@@ -279,13 +315,15 @@ public interface ScmProvider
      * @param endVersion   the end branch/tag/revision
      * @return The SCM result of the changelog command
      * @throws ScmException if any
+     * @deprecated use {@link #changeLog(org.apache.maven.scm.command.changelog.ChangeLogScmRequest)} instead
      */
+    @Deprecated
     ChangeLogScmResult changeLog( ScmRepository repository, ScmFileSet fileSet, ScmVersion startVersion,
                                   ScmVersion endVersion )
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system between two tags.
+     * Returns the changes that have happened in the source control system between two tags.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository  the source control system
@@ -296,15 +334,15 @@ public interface ScmProvider
      * @param datePattern the date pattern use in changelog output returned by scm tool
      * @return
      * @throws ScmException if any
-     * @deprecated you must use {@link ScmProvider#changeLog(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,org.apache.maven.scm.ScmVersion,String)}
+     * @deprecated use {@link #changeLog(org.apache.maven.scm.command.changelog.ChangeLogScmRequest)} instead
      */
+    @Deprecated
     ChangeLogScmResult changeLog( ScmRepository repository, ScmFileSet fileSet, String startTag, String endTag,
                                   String datePattern )
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system between two tags.
+     * Returns the changes that have happened in the source control system between two tags.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository    the source control system
@@ -315,7 +353,9 @@ public interface ScmProvider
      * @param datePattern   the date pattern use in changelog output returned by scm tool
      * @return
      * @throws ScmException if any
+     * @deprecated use {@link #changeLog(org.apache.maven.scm.command.changelog.ChangeLogScmRequest)} instead
      */
+    @Deprecated
     ChangeLogScmResult changeLog( ScmRepository repository, ScmFileSet fileSet, ScmVersion startRevision,
                                   ScmVersion endRevision, String datePattern )
         throws ScmException;
@@ -335,7 +375,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#checkIn(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,String)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, String)}
      */
     CheckInScmResult checkIn( ScmRepository repository, ScmFileSet fileSet, String tag, String message )
         throws ScmException;
@@ -384,7 +424,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#checkOut(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion)}
      */
     CheckOutScmResult checkOut( ScmRepository repository, ScmFileSet fileSet, String tag )
         throws ScmException;
@@ -422,7 +462,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#checkOut(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,boolean)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, boolean)}
      */
     CheckOutScmResult checkOut( ScmRepository scmRepository, ScmFileSet scmFileSet, String tag, boolean recursive )
         throws ScmException;
@@ -453,6 +493,22 @@ public interface ScmProvider
                                 boolean recursive )
         throws ScmException;
 
+    /**
+     * Create a copy of the repository on your local machine.
+     *
+     * @param scmRepository     the source control system
+     * @param scmFileSet        the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()}
+     *                          location
+     * @param version           get the version defined by the revision, branch or tag
+     * @param commandParameters parameters
+     * @return
+     * @throws ScmException if any
+     * @since 1.9.6
+     */
+    CheckOutScmResult checkOut( ScmRepository scmRepository, ScmFileSet scmFileSet, ScmVersion version , //
+                                CommandParameters commandParameters )
+        throws ScmException;
+
     /**
      * Create a diff between two branch/tag/revision.
      *
@@ -463,7 +519,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#diff(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,org.apache.maven.scm.ScmVersion)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, org.apache.maven.scm.ScmVersion)}
      */
     DiffScmResult diff( ScmRepository scmRepository, ScmFileSet scmFileSet, String startRevision, String endRevision )
         throws ScmException;
@@ -491,7 +547,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#export(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion)}
      */
     ExportScmResult export( ScmRepository repository, ScmFileSet fileSet, String tag )
         throws ScmException;
@@ -529,7 +585,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#export(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,String)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, String)}
      */
     ExportScmResult export( ScmRepository repository, ScmFileSet fileSet, String tag, String outputDirectory )
         throws ScmException;
@@ -579,11 +635,23 @@ public interface ScmProvider
      * @param fileSet    the files to tag. Implementations can also give the changes
      *                   from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param tagName    the tag name to apply to the files
+     * @return
+     * @throws ScmException if any
      * @deprecated use {@link #tag(ScmRepository, ScmFileSet, String, ScmTagParameters)}
+     */
+    TagScmResult tag( ScmRepository repository, ScmFileSet fileSet, String tagName )
+        throws ScmException;
+
+    /**
+     * Deletes a tag.
+     *
+     * @param repository the source control system
+     * @param fileSet    a fileset with the relevant working directory as basedir
+     * @param parameters
      * @return
      * @throws ScmException if any
      */
-    TagScmResult tag( ScmRepository repository, ScmFileSet fileSet, String tagName )
+    UntagScmResult untag( ScmRepository repository, ScmFileSet fileSet, CommandParameters parameters )
         throws ScmException;
 
     /**
@@ -594,27 +662,27 @@ public interface ScmProvider
      *                   from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param tagName    the tag name to apply to the files
      * @param message    the commit message used for the tag creation
-     * @deprecated use {@link #tag(ScmRepository, ScmFileSet, String, ScmTagParameters)}
      * @return
      * @throws ScmException if any
+     * @deprecated use {@link #tag(ScmRepository, ScmFileSet, String, ScmTagParameters)}
      */
     TagScmResult tag( ScmRepository repository, ScmFileSet fileSet, String tagName, String message )
         throws ScmException;
-    
+
     /**
      * Tag (or label in some systems) will tag the source file with a certain tag
      *
-     * @param repository         the source control system
-     * @param fileSet            the files to tag. Implementations can also give the changes
-     *                           from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
-     * @param tagName            the tag name to apply to the files
-     * @param scmTagParameters   bean to pass some paramters for tagging {@link ScmTagParameters}
+     * @param repository       the source control system
+     * @param fileSet          the files to tag. Implementations can also give the changes
+     *                         from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
+     * @param tagName          the tag name to apply to the files
+     * @param scmTagParameters bean to pass some paramters for tagging {@link ScmTagParameters}
      * @return
-     * @since 1.2
      * @throws ScmException if any
-     */    
+     * @since 1.2
+     */
     TagScmResult tag( ScmRepository repository, ScmFileSet fileSet, String tagName, ScmTagParameters scmTagParameters )
-        throws ScmException;    
+        throws ScmException;
 
     /**
      * Updates the copy on the local machine with the changes in the repository
@@ -636,7 +704,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion)}
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, String tag )
         throws ScmException;
@@ -663,7 +731,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,boolean)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, boolean)}
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, String tag, boolean runChangelog )
         throws ScmException;
@@ -703,7 +771,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,String)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, String)}
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, String tag, String datePattern )
         throws ScmException;
@@ -731,7 +799,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,java.util.Date)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, java.util.Date)}
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, String tag, Date lastUpdate )
         throws ScmException;
@@ -760,7 +828,7 @@ public interface ScmProvider
      * @return
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,org.apache.maven.scm.ScmVersion,java.util.Date,String)}
+     *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, java.util.Date, String)}
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, String tag, Date lastUpdate,
                             String datePattern )
@@ -796,7 +864,7 @@ public interface ScmProvider
 
     /**
      * Make a file no longer editable. This is the conterpart of {@link #edit(
-     * org.apache.maven.scm.repository.ScmRepository,org.apache.maven.scm.ScmFileSet)}.
+     *org.apache.maven.scm.repository.ScmRepository, org.apache.maven.scm.ScmFileSet)}.
      * It makes the file read-only again.
      *
      * @param repository the source control system
@@ -816,7 +884,7 @@ public interface ScmProvider
      * @param tag        use the version defined by the tag
      * @return the list of files in the repository
      * @deprecated you must use {@link ScmProvider#list(org.apache.maven.scm.repository.ScmRepository,
-     * org.apache.maven.scm.ScmFileSet,boolean,org.apache.maven.scm.ScmVersion)}
+     *             org.apache.maven.scm.ScmFileSet, boolean, org.apache.maven.scm.ScmVersion)}
      */
     ListScmResult list( ScmRepository repository, ScmFileSet fileSet, boolean recursive, String tag )
         throws ScmException;
@@ -833,4 +901,64 @@ public interface ScmProvider
      */
     ListScmResult list( ScmRepository repository, ScmFileSet fileSet, boolean recursive, ScmVersion version )
         throws ScmException;
+
+    /**
+     * Returns the blame of specified file
+     *
+     * @param repository the source control system
+     * @param fileSet    location of your local copy
+     * @param filename   file
+     * @return blame for specified file
+     * @throws ScmException
+     * @since 1.4
+     * @deprecated use blame with {@link BlameScmRequest} parameter
+     */
+    BlameScmResult blame( ScmRepository repository, ScmFileSet fileSet, String filename )
+        throws ScmException;
+
+    /**
+     *
+     * @param blameScmRequest
+     * @return blame for the file specified in the request
+     * @throws ScmException
+     * @since 1.8
+     */
+    BlameScmResult blame( BlameScmRequest blameScmRequest )
+        throws ScmException;
+
+
+    /**
+     * Create directory/directories in the repository.
+     *
+     * @param repository
+     * @param fileSet
+     * @param createInLocal
+     * @param message
+     * @return
+     * @throws ScmException
+     */
+    MkdirScmResult mkdir( ScmRepository repository, ScmFileSet fileSet, String message, boolean createInLocal )
+        throws ScmException;
+
+    /**
+     * @param repository the source control system
+     * @param fileSet    location of your local copy
+     * @param parameters some parameters (not use currently but for future use)
+     * @return if the scm implementation doesn't support "info" result will <code>null</code>
+     * @throws ScmException
+     * @since 1.5
+     */
+    InfoScmResult info( ScmProviderRepository repository, ScmFileSet fileSet, CommandParameters parameters )
+        throws ScmException;
+
+    /**
+     * @param repository the source control system
+     * @param fileSet    not use currently but for future use
+     * @param parameters some parameters (not use currently but for future use)
+     * @return if the scm implementation doesn't support "info" result will <code>null</code>
+     * @throws ScmException
+     * @since 1.6
+     */
+    RemoteInfoScmResult remoteInfo( ScmProviderRepository repository, ScmFileSet fileSet, CommandParameters parameters )
+        throws ScmException;
 }
