@@ -46,7 +46,7 @@ import org.codehaus.plexus.util.StringUtils;
 
 /**
  * @author <a href="mailto:george@neogrid.com.br">George Gastaldi</a>
- * @version $Id: VssScmProvider.java 885129 2009-11-28 19:13:15Z olamy $
+ *
  * @plexus.component role="org.apache.maven.scm.provider.ScmProvider" role-hint="vss"
  */
 public class VssScmProvider
@@ -130,7 +130,8 @@ public class VssScmProvider
         return (AddScmResult) command.execute( repository, fileSet, parameters );
     }
 
-    public CheckInScmResult checkin( ScmProviderRepository repository, ScmFileSet fileSet, CommandParameters parameters )
+    public CheckInScmResult checkin( ScmProviderRepository repository, ScmFileSet fileSet,
+                                     CommandParameters parameters )
         throws ScmException
     {
         VssCheckInCommand command = new VssCheckInCommand();
